==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ToolActionNumberInputInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionNumberInputInfoDescription } from "./ToolActionNumberInputInfoDescription";
/**
 * @hidden
 */
var ToolActionNumberInputInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionNumberInputInfoDescriptionMetadata, _super);
    function ToolActionNumberInputInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionNumberInputInfoDescriptionMetadata.b = function (a) {
        if (ToolActionNumberInputInfoDescriptionMetadata.a == null) {
            ToolActionNumberInputInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionNumberInputInfoDescriptionMetadata.c(ToolActionNumberInputInfoDescriptionMetadata.a);
        }
        if (a.k(ToolActionNumberInputInfoDescriptionMetadata.a)) {
            return;
        }
        a.ab(ToolActionNumberInputInfoDescriptionMetadata.a);
    };
    ToolActionNumberInputInfoDescriptionMetadata.c = function (a) {
        ToolActionInfoDescriptionMetadata.c(a);
        a.item("Value", "Number:double");
    };
    ToolActionNumberInputInfoDescriptionMetadata.d = function (a) {
        ToolActionNumberInputInfoDescriptionMetadata.b(a);
        a.ad("ToolActionNumberInputInfo", function () { return new ToolActionNumberInputInfoDescription(); });
        a.ac("ToolActionNumberInputInfo", ToolActionNumberInputInfoDescriptionMetadata.a);
    };
    ToolActionNumberInputInfoDescriptionMetadata.$t = markType(ToolActionNumberInputInfoDescriptionMetadata, 'ToolActionNumberInputInfoDescriptionMetadata');
    ToolActionNumberInputInfoDescriptionMetadata.a = null;
    return ToolActionNumberInputInfoDescriptionMetadata;
}(Base));
export { ToolActionNumberInputInfoDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ToolActionNumberInputInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionNumberInputInfoDescription } from "./ToolActionNumberInputInfoDescription";
/**
 * @hidden
 */
var ToolActionNumberInputInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionNumberInputInfoDescriptionMetadata, _super);
    function ToolActionNumberInputInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionNumberInputInfoDescriptionMetadata.b = function (a) {
        if (ToolActionNumberInputInfoDescriptionMetadata.a == null) {
            ToolActionNumberInputInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionNumberInputInfoDescriptionMetadata.c(ToolActionNumberInputInfoDescriptionMetadata.a);
        }
        if (a.k(ToolActionNumberInputInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(ToolActionNumberInputInfoDescriptionMetadata.a);
    };
    ToolActionNumberInputInfoDescriptionMetadata.c = function (a) {
        ToolActionInfoDescriptionMetadata.c(a);
        a.item("Value", "Number:double");
    };
    ToolActionNumberInputInfoDescriptionMetadata.d = function (a) {
        ToolActionNumberInputInfoDescriptionMetadata.b(a);
        a.ae("ToolActionNumberInputInfo", function () { return new ToolActionNumberInputInfoDescription(); });
        a.ad("ToolActionNumberInputInfo", ToolActionNumberInputInfoDescriptionMetadata.a);
    };
    ToolActionNumberInputInfoDescriptionMetadata.$t = markType(ToolActionNumberInputInfoDescriptionMetadata, 'ToolActionNumberInputInfoDescriptionMetadata');
    ToolActionNumberInputInfoDescriptionMetadata.a = null;
    return ToolActionNumberInputInfoDescriptionMetadata;
}(Base));
export { ToolActionNumberInputInfoDescriptionMetadata };
